@@ -27,7 +27,7 @@ def general_exception(
             traceback.format_exception(etype=type(exc), value=exc, tb=exc.__traceback__)
         )
         print(tb)
-        debug_info[f"{CONFIG.provider['prefix']}traceback"] = tb
+        debug_info[f"_{CONFIG.provider.prefix}_traceback"] = tb
 
     try:
         http_response_code = exc.status_code
@@ -59,7 +59,7 @@ def general_exception(
         # This was introduced due to the original raise of an HTTPException if the
         # path prefix could not be found, e.g., `/v0`.
         # However, due to the testing, this error cannot be raised anymore.
-        # Instead, an OPTiMaDe warning should be issued.
+        # Instead, an OPTIMADE warning should be issued.
         # Having this try and except is still good practice though.
         response = ErrorResponse(errors=errors)
 
@@ -108,5 +108,13 @@ def grammar_not_implemented_handler(request: Request, exc: VisitError):
     return general_exception(request, exc, status_code=status, errors=[error])
 
 
+def not_implemented_handler(request: Request, exc: NotImplementedError):
+    status = 501
+    title = "NotImplementedError"
+    detail = str(exc)
+    error = OptimadeError(detail=detail, status=status, title=title)
+    return general_exception(request, exc, status_code=status, errors=[error])
+
+
 def general_exception_handler(request: Request, exc: Exception):
     return general_exception(request, exc)
