@@ -53,17 +53,15 @@ def meta_values(
     else:
         url_path = parse_result.path
 
-    provider = CONFIG.provider.copy()
-    provider["prefix"] = provider["prefix"][1:-1]  # Remove surrounding `_`
     return ResponseMeta(
         query=ResponseMetaQuery(representation=f"{url_path}?{parse_result.query}"),
         api_version=f"v{__api_version__}",
         time_stamp=datetime.utcnow(),
         data_returned=data_returned,
         more_data_available=more_data_available,
-        provider=Provider(**provider),
+        provider=CONFIG.provider,
         data_available=data_available,
-        implementation=Implementation(**CONFIG.implementation),
+        implementation=CONFIG.implementation,
         **kwargs,
     )
 
@@ -280,10 +278,6 @@ def retrieve_queryable_properties(schema: dict, queryable_properties: list) -> d
                 properties.update(
                     retrieve_queryable_properties(sub_schema, sub_queryable_properties)
                 )
-            elif value.get("description", "") == "Not allowed key":
-                # Special case used in models to make sure not-allowed fields are not present under "attributes"
-                # NOTE: This may be removed when upgrading to pydantic v1 !
-                continue
             else:
                 properties[name] = {"description": value.get("description", "")}
                 if "unit" in value:
